import { NextRequest, NextResponse } from "next/server";

export async function POST(req: NextRequest) {
  try {
    const { titleKeyword, type, apiKey } = await req.json();
    // console.log("Received request:", { title, type, apiKey });

    if (!apiKey) {
      console.error("❌ Missing OpenAI API Key");
      return NextResponse.json({ error: "Missing OpenAI API Key" }, { status: 400 });
    }

    // 📝 Define word count for each article type
    const prompts: Record<string, string> = {
        "Blog Article": "Blog Article",
        "YouTube Video": "YouTube Video",
        "How-To Titles": "How-To Titles",
        "Question Titles": "Question Titles",
        "Comparison Titles": "Comparison Titles",
        "News Headlines": "News Headlines",
      };
      

      const prompt = `Generate a list of 30 engaging and SEO-optimized titles based on the given keywords: **"${titleKeyword}"**. 

      **Guidelines:**  
      - Each title must match the style of a **${prompts[type]}**.  
      - Keep an **SEO score of 80+** and a **readability score of 80+**.  
      - Use **emotional words** to capture attention.  
      - Avoid complex language while maintaining depth.  
      - Do not use common or overused phrases.  
      - Maintain the correct word count based on the type of content.  
      - Titles should be **clear, concise, and compelling**.
      
      **Examples of Good Titles:**  
      1. How to [Achieve Desired Outcome] in [Timeframe]  
      2. The Ultimate Guide to [Topic] – Everything You Need to Know  
      3. [X] Surprising Facts About [Topic] You Didn’t Know  
      4. [X] Common Mistakes to Avoid When [Activity]  
      5. Why [Topic] Matters More Than Ever in [Year]  
      
      Generate 30 such titles, ensuring they are diverse and engaging.`;
      
    console.log("Generated prompt:", prompt);

      // 🌍 Call OpenAI API
      const response = await fetch("https://api.openai.com/v1/chat/completions", {
        method: "POST",
        headers: {
          
          "Content-Type": "application/json",
          "Authorization": `Bearer ${apiKey}`,
        },
        body: JSON.stringify({
          model: "gpt-4o-mini",
          messages: [
              { role: "user", content: prompt },  // Using the prompt here as a message from the user
            ],
            temperature: 0.7,  // Adjust temperature for creativity
          max_tokens: 1000,
        }),
      });
    if (!response.ok) {
      console.error("❌ Error calling OpenAI API:", response.status, response.statusText);
      return NextResponse.json({ error: "Failed to generate article from OpenAI" }, { status: 500 });
    }

    const data = await response.json();
    console.log("OpenAI response:", data);

    if (!data.choices || data.choices.length === 0) {
      console.error("❌ No choices in OpenAI response");
      return NextResponse.json({ error: "No content returned from OpenAI" }, { status: 500 });
    }

    return NextResponse.json({ content: data.choices[0].message.content });

  } catch (error) {
    console.error("❌ Error in OpenAI request:", error);
    return NextResponse.json({ error: "Failed to generate article" }, { status: 500 });
  }
}
